- `Official Python FAQ - global and local <https://docs.python.org/3/faq/programming.html#what-are-the-rules-for-local-and-global-variables-in-python>`_
- `PEP 3104 - Access to Names in Outer Scopes <https://peps.python.org/pep-3104/>`_
- `Python global statement <https://docs.python.org/3/reference/simple_stmts.html#global>`_
